package com.datacloudsec.scan.service.impl;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.dao.TaskMapper;
import com.datacloudsec.scan.entity.LicCmp;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.service.ICommon;
import com.datacloudsec.scan.service.ITaskBase;
import com.datacloudsec.scan.tasks.scheduler.PeriodTask;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.scan.tasks.scheduler.job.ScanJob;
import com.datacloudsec.scan.tasks.scheduler.time.TimeIntervalHour;
import com.datacloudsec.scan.tasks.scheduler.time.TimeMonthly;
import com.datacloudsec.scan.tasks.scheduler.time.TimeMutilDay;
import com.datacloudsec.scan.tasks.scheduler.time.TimeWeek;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/TaskBaseService.class */
public class TaskBaseService implements ITaskBase {
    private TaskMapper taskMapper = (TaskMapper) InstanceUtil.newDaoInstance(TaskMapper.class);
    private ICommon commonService = (ICommon) InstanceUtil.newServiceInstance(CommonService.class);
    private Logger LOG = Logger.getLogger(TaskBaseService.class);

    public int searchCount(HttpSession session, String name, Integer status, Integer type) throws Exception {
        return this.taskMapper.searchCount(name, status, DataRule.getRuleWhere(session, "t_task"), type);
    }

    public List<Map<String, Object>> search(HttpSession session, String name, Integer status, Integer offset, Integer limit, Integer type) throws Exception {
        return this.taskMapper.search(name, status, offset, limit, DataRule.getRuleWhere(session, "t_task"), type);
    }

    public Task getTaskById(HttpSession session, Integer id) throws Exception {
        Map<String, Object> map;
        if (session != null && ((map = this.commonService.queryRule(session, id, "t_task")) == null || map.size() == 0)) {
            throw new UEException("当前用户没有权限");
        }
        return this.taskMapper.getTaskById(id);
    }

    public List<Map<String, Object>> getEmailForTask(Integer uid) throws Exception {
        return this.taskMapper.getEmailForTask(uid);
    }

    public List<Map<String, Object>> getPhoneForTask(Integer uid) throws Exception {
        return this.taskMapper.getPhoneForTask(uid);
    }

    public List<Map<String, Object>> getTaskDevByTid(Integer taskId) {
        return this.taskMapper.getTaskDevByTid(taskId);
    }

    public Integer queryTaskDevCount(String name, Integer type, Integer status, Integer taskId) throws Exception {
        return this.taskMapper.queryTaskDevCount(name, type, status, taskId);
    }

    public Map<String, Object> getTaskDevById(HttpSession session, Integer id) throws Exception {
        if (session != null) {
            Task task = this.taskMapper.getTaskBydevId(id);
            Map<String, Object> map = this.commonService.queryRule(session, task.getId(), "t_task");
            if (map == null || map.size() == 0) {
                throw new UEException("当前用户没有权限");
            }
        }
        return this.taskMapper.getTaskDevById(id);
    }

    public Integer getTaskDevCountByTid(Integer taskId) throws Exception {
        return this.taskMapper.getTaskDevCountByTid(taskId);
    }

    public List<Map<String, Object>> getDevByType(HttpSession session, String type, Integer dtype, String name, Integer regionSid, Integer regionCid, String ip, String[] dgid, Integer offset, Integer limit) throws Exception {
        return this.taskMapper.getDevByType(type, dtype, name, regionSid, regionCid, ip, dgid, DataRule.getRuleWhere(session, "t_device"), offset, limit);
    }

    public Integer getDevCountByType(HttpSession session, String type, Integer dtype, String name, Integer regionSid, Integer regionCid, String ip, String[] dgid) throws Exception {
        return this.taskMapper.getDevCountByType(type, dtype, name, regionSid, regionCid, ip, dgid, DataRule.getRuleWhere(session, "t_device"));
    }

    public void startTimer(Integer taskid, Integer type, String periodTime, Integer alarmType, String alarmMethod, String alarmTime) throws Exception {
        if (type.intValue() == 2) {
            String[] entryPeriod = periodTime.split(":");
            String periodId = "scan_" + taskid;
            if (periodTime.charAt(0) == '0') {
                Map<String, Object> map = new HashMap<>();
                map.put("taskid", taskid);
                PeriodTask.getInstance().addJob(ScanJob.class, new TimeMonthly(ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue(), ObjectUtil.getInt(entryPeriod[3]).intValue()), periodId, map);
            } else if (periodTime.charAt(0) == '1') {
                Map<String, Object> map2 = new HashMap<>();
                map2.put("taskid", taskid);
                PeriodTask.getInstance().addJob(ScanJob.class, new TimeWeek(ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue(), ObjectUtil.getInt(entryPeriod[3]).intValue()), periodId, map2);
            } else if (periodTime.charAt(0) == '2') {
                Map<String, Object> map3 = new HashMap<>();
                map3.put("taskid", taskid);
                PeriodTask.getInstance().addJob(ScanJob.class, new TimeMutilDay(0, ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue()), periodId, map3);
            } else if (periodTime.charAt(0) == '3') {
                Map<String, Object> map4 = new HashMap<>();
                map4.put("taskid", taskid);
                PeriodTask.getInstance().addJob(ScanJob.class, new TimeMutilDay(ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue(), ObjectUtil.getInt(entryPeriod[3]).intValue()), periodId, map4);
            } else if (periodTime.charAt(0) == '4') {
                Map<String, Object> map5 = new HashMap<>();
                map5.put("taskid", taskid);
                PeriodTask.getInstance().addJob(ScanJob.class, new TimeIntervalHour(ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue(), 0), periodId, map5);
            }
        }
        if (alarmType.intValue() == 2) {
            if (alarmMethod.contains("mail") || alarmMethod.contains("sms")) {
                String[] at = alarmTime.split(":");
                Map<String, Object> map6 = new HashMap<>();
                map6.put("taskid", taskid);
                PeriodTask.getInstance().addJob(AlermJob.class, new TimeMutilDay(0, ObjectUtil.getInt(at[0]).intValue(), ObjectUtil.getInt(at[1]).intValue()), "alerm_" + taskid, map6);
            }
        }
    }

    public void startTimer(HttpSession session, Integer taskid) throws Exception {
        List<Map<String, Object>> list = this.taskMapper.searchTimer(taskid, DataRule.getRuleWhere(session, "t_task"));
        for (Map<String, Object> m : list) {
            Integer tid = ObjectUtil.getInt(m.get("id"));
            Integer type = Integer.valueOf(ObjectUtil.getInt(m.get("type"), 0));
            String periodTime = ObjectUtil.getString(m.get("periodTime"), "-");
            Integer alarmType = ObjectUtil.getInt(m.get("alarmType"));
            String alarmMethod = ObjectUtil.getString(m.get("alarmMethod"), "");
            String alarmTime = ObjectUtil.getString(m.get("alarmTime"), "");
            startTimer(tid, type, periodTime, alarmType, alarmMethod, alarmTime);
        }
    }

    public void stopTimer(HttpSession session, Integer taskid) throws Exception {
        if (taskid == null) {
            List<Map<String, Object>> list = this.taskMapper.searchTimer((Integer) null, DataRule.getRuleWhere(session, "t_task"));
            for (Map<String, Object> m : list) {
                Object tid = m.get("id");
                PeriodTask.getInstance().removeJob("alerm_" + tid);
                PeriodTask.getInstance().removeJob("scan_" + tid);
            }
            return;
        }
        PeriodTask.getInstance().removeJob("alerm_" + taskid);
        PeriodTask.getInstance().removeJob("scan_" + taskid);
    }

    public int searchWebCount(HttpSession session, String name, String title, String server, String xpowerdby, Integer status, Integer tamperStatus, Integer availStatus, Integer type) throws Exception {
        return this.taskMapper.searchWebCount(name, title, server, xpowerdby, status, tamperStatus, availStatus, DataRule.getRuleWhere(session, "t_task"), type);
    }

    public List<Map<String, Object>> searchWeb(HttpSession session, String name, String title, String server, String xpowerdby, Integer status, Integer tamperStatus, Integer availStatus, Integer type, Integer offset, Integer limit) throws Exception {
        return this.taskMapper.searchWeb(name, title, server, xpowerdby, status, tamperStatus, availStatus, offset, limit, DataRule.getRuleWhere(session, "t_task"), type);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public LicCmp getLicCp(String cmps, String cmp) {
        int maxdevice = 5;
        int authDay = 0;
        int maxReq = 0;
        String[] split = cmps.split("/");
        int length = split.length;
        int i = 0;
        while (true) {
            if (i >= length) {
                break;
            }
            String mod = split[i];
            if (!mod.startsWith(cmp)) {
                i++;
            } else {
                String[] modEntry = mod.split(":");
                if (modEntry.length >= 2) {
                    authDay = ObjectUtil.getInt(modEntry[1], 0);
                }
                if (modEntry.length >= 3) {
                    maxdevice = ObjectUtil.getInt(modEntry[2], 5);
                }
                if (modEntry.length >= 4) {
                    maxReq = ObjectUtil.getInt(modEntry[3], 10);
                }
            }
        }
        return new LicCmp(Integer.valueOf(authDay), maxdevice, maxReq);
    }

    public Task getTaskBydevId(HttpSession session, Integer devid) throws Exception {
        Map<String, Object> map;
        Task task = this.taskMapper.getTaskBydevId(devid);
        if (session != null && ((map = this.commonService.queryRule(session, task.getId(), "t_task")) == null || map.size() == 0)) {
            throw new UEException("当前用户没有权限");
        }
        return task;
    }

    public Map<String, Object> getTaskDevByTidAndIp(Integer id, String ip) throws Exception {
        return this.taskMapper.getTaskDevByTidAndIp(id, ip);
    }

    public List<Map<String, Object>> getTaskTreeByIds(Integer[] ids) throws Exception {
        return this.taskMapper.getTaskTreeByIds(ids);
    }

    public List<Map<String, Object>> searchById(HttpSession session, String[] ids) {
        return this.taskMapper.searchById(ids, DataRule.getRuleWhere(session, "t_task"));
    }
}
